@@ -1,4 +1,5 @@
-from typing import Optional
+from types import SimpleNamespace
+from typing import Optional, Union
 
 from discord_gateway import Embed
 from discord_gateway.api import HttpClient
@@ -11,7 +12,7 @@ __all__ = (
 
 class CommandContext(DiscordMessage):
 
-    def __init__(self, data: object | dict, client: HttpClient):
+    def __init__(self, data: Union[dict, SimpleNamespace], client: HttpClient):
         super().__init__(data, client)
         self.api = client
 
